[![DOI](https://zenodo.org/badge/103197335.svg)](https://zenodo.org/badge/latestdoi/103197335)
[![Python 3.6](https://img.shields.io/badge/python-3.6-green.svg)](https://www.python.org/downloads/release/python-365/)
[![Build Status](https://ci.commonwl.org/buildStatus/icon?job=airflow-conformance)](https://ci.commonwl.org/job/airflow-conformance)


# **CWL-Airflow**

Python package to extend **[Apache-Airflow 1.10.5](https://github.com/apache/incubator-airflow)**
functionality with **[CWL v1.1](https://www.commonwl.org/v1.1/)** support.


## **Cite as**

Michael Kotliar, Andrey V Kartashov, Artem Barski, CWL-Airflow: a lightweight pipeline manager supporting Common Workflow Language, GigaScience, Volume 8, Issue 7, July 2019, giz084, https://doi.org/10.1093/gigascience/giz084

## **Get the latest version**
```
pip install cwl-airflow
```
Latest version [documentation](https://cwl-airflow.readthedocs.io/en/latest/)


## **Get published version**
```
pip install cwl-airflow==1.0.16
```
Published version [documentation](https://cwl-airflow.readthedocs.io/en/1.0.18/)
